==> jaulp.wicket.components-6.20.2-sources.jar: de/alpharogroup/wicket/components/i18n/list/HeaderContentListModelBean.java <==
/**
 * Copyright (C) 2010 Asterios Raptis
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.alpharogroup.wicket.components.i18n.list;

import java.io.Serializable;
import java.util.List;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.NonNull;
import lombok.Setter;
import lombok.ToString;
import de.alpharogroup.locale.ResourceBundleKey;


/**
 * The Class {@link HeaderContentListModelBean} holds data for the resource key of header and a list of content objects.
 *
 * @author Asterios Raptis
 */
@Getter
@Setter
@EqualsAndHashCode
@ToString
@NoArgsConstructor
@AllArgsConstructor
@Builder
public class HeaderContentListModelBean implements Serializable
{

	/**
	 * The serialVersionUID
	 */
	private static final long serialVersionUID = 1L;	
	/**
	 * The resource bundle key for the header.
	 */
	@NonNull
	private ResourceBundleKey headerResourceKey;
	
	/**
	 * The list of resource bundle keys for the content.
	 */
	@NonNull
	private List<ResourceBundleKey> contentResourceKeys;

}

==> jaulp.wicket.components-6.25.0-sources.jar: de/alpharogroup/wicket/components/i18n/list/HeaderContentListModelBean.java <==
/**
 * Copyright (C) 2010 Asterios Raptis
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.alpharogroup.wicket.components.i18n.list;

import java.io.Serializable;
import java.util.List;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.EqualsAndHashCode;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.NonNull;
import lombok.Setter;
import lombok.ToString;
import de.alpharogroup.resourcebundle.locale.ResourceBundleKey;


/**
 * The Class {@link HeaderContentListModelBean} holds data for the resource key of header and a list of content objects.
 *
 * @author Asterios Raptis
 */
@Getter
@Setter
@EqualsAndHashCode
@ToString
@NoArgsConstructor
@AllArgsConstructor
@Builder
public class HeaderContentListModelBean implements Serializable
{

	/**
	 * The serialVersionUID
	 */
	private static final long serialVersionUID = 1L;	
	/**
	 * The resource bundle key for the header.
	 */
	@NonNull
	private ResourceBundleKey headerResourceKey;
	
	/**
	 * The list of resource bundle keys for the content.
	 */
	@NonNull
	private List<ResourceBundleKey> contentResourceKeys;

}
